# python-package_build

Install -> setupttools, twine and wheel

1.Create package_dir with  __init__.py and modules inside it.
Also, add setup.py and can also add README.md and LICENSE.txt as optional 

2.Then build with python3 setup.py sdist bdist_wheel cmd

